type Comparator<T> = (a: T, b: T) => number;
/**
 * Entry returned by {@link merge} when `outputMetadata: true` is given
 */
type Entry<T> = [
    indexOfSourceArray: number,
    indexInSourceArray: number,
    value: T
];
/**
 * Options for {@link merge}
 */
export type MergeOptions<T> = {
    /**
     * The function to compare array elements
     */
    comparator?: Comparator<T>;
    /**
     * If true, outputs {@link Entry} tuples instead of just values:
     * [indexOfSourceArray: number, indexInSourceArray: number, value: T]
     */
    outputMetadata?: boolean;
    /**
     * If true, filters out duplicate values (for which comparator(prev, next) === 0).
     * When using with `outputMetadata: true`, the last occurrence of a value in the last array
     * containing that value wins.
     */
    unique?: boolean;
};
export default function merge<T>(
/**
 * The arrays to merge, which must each be sorted
 */
arrays: T[][], options: MergeOptions<T> & {
    outputMetadata: true;
}): Entry<T>[];
export default function merge<T>(
/**
 * The arrays to merge, which must each be sorted
 */
arrays: T[][], options?: MergeOptions<T> | Comparator<T>): T[];
export {};
//# sourceMappingURL=index.d.ts.map