"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = merge;
var _tinyqueue = _interopRequireDefault(require("tinyqueue"));
function defaultComparator(a, b) {
  return a < b ? -1 : a > b ? 1 : 0;
}

/**
 * Entry returned by {@link merge} when `outputMetadata: true` is given
 */

/**
 * Options for {@link merge}
 */

function merge(
/**
 * The arrays to merge, which must each be sorted
 */
arrays, options) {
  var comparator,
    outputMetadata = false,
    unique = false;
  if (typeof options === 'function') {
    comparator = options;
  } else if (options) {
    comparator = options.comparator;
    outputMetadata = options.outputMetadata;
    unique = options.unique;
  }
  var finalComparator = comparator || defaultComparator;
  var entryComparator = unique ? function (a, b) {
    return finalComparator(a[2], b[2]) || b[0] - a[0];
  } : function (a, b) {
    return finalComparator(a[2], b[2]);
  };
  var totalLength = arrays.reduce(function (length, array) {
    return length + array.length;
  }, 0);
  var output = new Array(totalLength);
  var outputIndex = 0;
  var initQueue = arrays.reduce(function (initQueue, array, index) {
    if (array.length) initQueue.push([index, 0, array[0]]);
    return initQueue;
  }, []);
  var queue = new _tinyqueue["default"](initQueue, entryComparator);
  var prev;
  var entry;
  while (entry = queue.pop()) {
    if (!unique || !prev || finalComparator(entry[2], prev[2]) !== 0 && (entry[1] === arrays[entry[0]].length - 1 || finalComparator(entry[2], arrays[entry[0]][entry[1] + 1]) < 0)) {
      prev = entry;
      output[outputIndex++] = outputMetadata ? entry : entry[2];
    }
    var array = arrays[entry[0]];
    var nextIndex = entry[1] + 1;
    if (nextIndex < array.length) {
      queue.push([entry[0], nextIndex, array[nextIndex]]);
    }
  }
  if (unique) output.length = outputIndex;
  return output;
}
module.exports = exports.default;
//# sourceMappingURL=index.js.map