import TinyQueue from 'tinyqueue';
function defaultComparator(a, b) {
  return a < b ? -1 : a > b ? 1 : 0;
}

/**
 * Entry returned by {@link merge} when `outputMetadata: true` is given
 */

/**
 * Options for {@link merge}
 */

export default function merge(
/**
 * The arrays to merge, which must each be sorted
 */
arrays, options) {
  let comparator,
    outputMetadata = false,
    unique = false;
  if (typeof options === 'function') {
    comparator = options;
  } else if (options) {
    comparator = options.comparator;
    outputMetadata = options.outputMetadata;
    unique = options.unique;
  }
  const finalComparator = comparator || defaultComparator;
  const entryComparator = unique ? (a, b) => finalComparator(a[2], b[2]) || b[0] - a[0] : (a, b) => finalComparator(a[2], b[2]);
  const totalLength = arrays.reduce(function (length, array) {
    return length + array.length;
  }, 0);
  const output = new Array(totalLength);
  let outputIndex = 0;
  const initQueue = arrays.reduce(function (initQueue, array, index) {
    if (array.length) initQueue.push([index, 0, array[0]]);
    return initQueue;
  }, []);
  const queue = new TinyQueue(initQueue, entryComparator);
  let prev;
  let entry;
  while (entry = queue.pop()) {
    if (!unique || !prev || finalComparator(entry[2], prev[2]) !== 0 && (entry[1] === arrays[entry[0]].length - 1 || finalComparator(entry[2], arrays[entry[0]][entry[1] + 1]) < 0)) {
      prev = entry;
      output[outputIndex++] = outputMetadata ? entry : entry[2];
    }
    const array = arrays[entry[0]];
    const nextIndex = entry[1] + 1;
    if (nextIndex < array.length) {
      queue.push([entry[0], nextIndex, array[nextIndex]]);
    }
  }
  if (unique) output.length = outputIndex;
  return output;
}
//# sourceMappingURL=index.mjs.map